# LicenseConstraintName

The well-known name of the constraint. This is used by the system when evaluating whether an operation is allowed by a license, or in prodividing information about the license: a given constraint is identified by name by components of the system as part of a contract agreed upon when building a feature. Constraints may refer to other constraints by name. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The well-known name of the constraint. This is used by the system when evaluating whether an operation is allowed by a license, or in prodividing information about the license: a given constraint is identified by name by components of the system as part of a contract agreed upon when building a feature. Constraints may refer to other constraints by name.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


